const ICONS = [
    'sports_soccer', 'sports_basketball', 'sports_volleyball', 'sports_tennis',
    'sports_football', 'sports_baseball', 'sports_hockey', 'sports_handball',
    'directions_run', 'fitness_center', 'sports_score', 'emoji_events'
];


// Add required styles to the document

const style = document.createElement('style');
style.textContent = `
    @import url('https://fonts.googleapis.com/css2?family=Material+Symbols+Outlined:opsz,wght,FILL,GRAD@20..48,100..700,0..1,-50..200');
    
    .floating-icon {
        width: 200px;
        height: 100px;
        background: rgba(255, 255, 255, 0.04);
        border-radius: 12px;
        display: flex;
        align-items: center;
        justify-content: center;
        z-index: -1;
    }
    
    .material-symbols-outlined {
        font-size: 32px;
        color: rgba(255, 255, 255, 0.1);
    }
`;
document.head.appendChild(style);


class Block {
    constructor() {
        this.icon = ICONS[Math.floor(Math.random() * ICONS.length)];
        this.element = document.createElement('div');
        this.element.className = 'floating-icon';
        
        const iconElement = document.createElement('span');
        iconElement.className = 'material-symbols-outlined';
        iconElement.textContent = this.icon;
        
        // Generate random alpha value between 0.2 and 0.75
        const alpha = 0.4 + Math.random() * 0.8;
        iconElement.style.backgroundColor = `rgba(255, 255, 255, ${alpha})`;
        iconElement.style.webkitBackgroundClip = 'text';
        iconElement.style.backgroundClip = 'text';
        iconElement.style.webkitTextFillColor = 'transparent';
        
        this.element.appendChild(iconElement);
    }
}


class LinesSpawner {
    constructor() {
        this.element = document.createElement('div');
        this.element.style = `
            display: flex;
            flex-direction: column;
            gap: 6px;
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            z-index: -1;
            justify-content: center;
            opacity: 0;
            transition: opacity 4s ease;
        `;

        document.body.appendChild(this.element);

        this.lines = [
            new Line(1),
            new Line(1.1),
            new Line(1.2)
        ];

        this.lines.forEach(line => {
            this.element.appendChild(line.element);
        });

        // Trigger fade in after a brief delay
        requestAnimationFrame(() => {
            this.element.style.opacity = '0.2';
        });
    }
}

class Line {
    constructor(basespeed) {
        this.basespeed = basespeed;
        this.icons = [];
        for (let i = 0; i < 24; i++) {
            this.icons.push(new Block());
        }
        
        this.element = document.createElement('div');
        this.element.style.display = 'flex';
        this.element.style.flexDirection = 'row';
        this.element.style.gap = '6px';
        this.element.style.width = '100%';
        this.element.style.overflow = 'hidden';
        this.element.style.position = 'relative';

        this.container = document.createElement('div');
        this.container.style.display = 'flex';
        this.container.style.flexDirection = 'row';
        this.container.style.gap = '6px';

        // Create two sets of icons for seamless scrolling
        this.icons.forEach(icon => {
            this.container.appendChild(icon.element);
        });
        
        // Clone the icons for seamless loop
        const clonedIcons = this.icons.map(icon => {
            const clonedBlock = new Block();
            clonedBlock.icon = icon.icon;
            return clonedBlock;
        });
        
        clonedIcons.forEach(icon => {
            this.container.appendChild(icon.element);
        });

        this.element.appendChild(this.container);
        
        // Calculate total width of one set
        const iconWidth = 206; // 200px width + 6px gap
        this.resetPoint = iconWidth * this.icons.length;

        // Start animation
        this.animate();
    }

    animate() {
        let position = 0;
        
        const step = () => {
            position -= this.basespeed;
            
            // Reset position when first set is fully scrolled
            if (Math.abs(position) >= this.resetPoint) {
                position += this.resetPoint;
            }
            
            this.container.style.transform = `translateX(${position}px)`;
            requestAnimationFrame(step);
        };

        requestAnimationFrame(step);
    }
}


new LinesSpawner();